#!/bin/sh

echo ""
echo "===== Thrift Daemon Control ====="

THRIFTDIR=/tmp/thrift
LOGFILE=$THRIFTDIR/thrift.log
PIDFILE=$THRIFTDIR/thrift.pid

STOP_TIMEOUT=3

USAGE="Usage: thriftctl.sh (start|stop)"

if [ $# -lt 1 ]; then
  echo $USAGE
  echo ""
  exit 1
fi

# Setup Environment
if [ -z "$GSDLHOME" ]; then
    echo "Warning! Assuming relative paths - will only work if running script <gsdl>/ext/parallel-processing/packages/ThriftFS-0.9.0/bin"
    GEXTPARALLELBUILDING=../../../
    HADOOP_PREFIX=../../hadoop-1.1.0
fi

if [ -z "$GEXTPARALLELBUILDING" ]; then
    echo "Error! GEXTPARALLELBUILDING not set, run setup.bash in Parallel Building extension directory"
    echo ""
    exit 1
fi

COMMAND=$1
shift
# Default port number
PORT=58660
if [ -n "$1" ]; then
  PORT=$1
  shift
fi

case $COMMAND in

    (start)

        echo "Starting ThriftFS Server..."
        if [ -f "$PIDFILE" ]; then
            TARGET_PID=`cat $PIDFILE`
            if kill -0 $TARGET_PID > /dev/null 2>&1; then
                echo "  server already running (pid: $TARGET_PID)"
                echo "Complete!"
                echo ""
                exit 1
            fi
        fi

        if [ ! -d "$THRIFTDIR" ]; then
            echo "  creating Thrift tmp directory: $THRIFTDIR"
            mkdir -p "$THRIFTDIR"
        fi

        echo "  determining CLASSPATH"
        # the hadoop configuration path
        HADOOP_CONF_DIR=$HADOOP_PREFIX/conf/
        # build up classpath
        CLASSPATH=${HADOOP_CONF_DIR}
        for f in ${HADOOP_PREFIX}/*.jar ; do
            CLASSPATH=$CLASSPATH:$f
        done
        for f in ${HADOOP_PREFIX}/lib/*.jar ; do
            CLASSPATH=$CLASSPATH:$f
        done
        for f in ${GEXTPARALLELBUILDING}/packages/ThriftFS-0.9.0/*.jar ; do
            CLASSPATH=$CLASSPATH:$f
        done
        for f in ${GEXTPARALLELBUILDING}/packages/ThriftFS-0.9.0/lib/*.jar ; do
            CLASSPATH=$CLASSPATH:$f
        done

        echo "  starting server"
        java -Dcom.sun.management.jmxremote -cp "$CLASSPATH" org.apache.hadoop.thriftfs.HadoopThriftServer $PORT $* > "$LOGFILE" 2>&1 < /dev/null &
        echo $! > "$PIDFILE"
        echo "  server started (pid: $!)"
        ;;

    (stop)

        echo "Stopping ThriftFS Server..."
        if [ -d "$THRIFTDIR" -a -f "$PIDFILE" ]; then
            TARGET_PID=`cat $PIDFILE`
            if kill -0 $TARGET_PID > /dev/null 2>&1; then
                echo "  stopping server (pid: $TARGET_PID)"
                kill $TARGET_PID
                sleep $STOP_TIMEOUT
                if kill -0 $TARGET_PID > /dev/null 2>&1; then
                    echo "  server did not stop gracefully after $STOP_TIMEOUT seconds: killing with kill -9"
                    kill -9 $TARGET_PID
                fi
                rm $PIDFILE
            else
                echo "  no server to stop"
            fi
        else
            echo "  no server to stop"
        fi

        DATETIME=`date +"%y/%m/%d %T"`
        echo "$DATETIME INFO hadoop.thrift: Stopping the hadoop thrift server" >> "$LOGFILE"
        ;;

    (*)

        echo "Unrecognized command"
        echo $USAGE
        exit 1
        ;;

esac

echo "Complete!"
echo ""